from distutils.core import setup

setup(
    name='pad-on-left',
    version='1.0.0',
    packages=['pad_on_left'],
    url='https://github.com/ErnstHaagsman/pad-on-left',
    license='Apache 2.0',
    author='Ernst Haagsman',
    author_email='ernst.haagsman@jetbrains.com',
    description='A python implementation of left-pad'
)
